# future-uuid
A backport of the uuid6, uuid7 and uuid8 implementations from python3.14 to python 3.9+



```bash
pip install future-uuid
```

```python
import future_uuid

x = future_uuid.uuid6()
y = future_uuid.uuid7()
z = future_uuid.uuid8()
```
